# grey.tcl ---
#
# Copyright (c) 2007-2009 Johann Oberdorfer
#
# $Id: grey.tcl,v 1.10 2009/02/20 15:14:37 oberdorfer Exp $

package require Tk 8.4;                 # minimum version for Tile
package require tile 0.8;               # depends upon tile
# package require ttk::theme::smog;       # the parent theme


namespace eval ttk {
  namespace eval theme {
    namespace eval grey {
      variable version 0.0.1
    }
  }
}

namespace eval ::ttk::theme::grey {

  variable dir [file dirname [info script]]
  
  # these colors must be in sync with the ones probably
  # declared in a corresponding "grey.rdb" resource file
  variable colors

  array set colors {
      SystemWindow        "#6e7c94"
      SystemWindowFrame   "#788c9c"
      SystemWindowText    "White"
      SystemButtonFace    "#6e7c94"
      SystemButtonText    "Black"
      SystemDisabledText  "#aaaaaa"
      SystemHighlight     "#4a6984"
      SystemHighlightText "White"
      SystemMenu          "#6e7c94"
      SystemMenuText      "White"
      SystemScrollbar     "#788c9c"
  }

  # Theme defaults

  ::ttk::style theme create grey -parent clam -settings {

    ::ttk::style configure "." \
        -foreground       $colors(SystemWindowText) \
        -background       $colors(SystemWindowFrame) \
        -bordercolor      $colors(SystemButtonFace) \
        -selectbackground $colors(SystemHighlight) \
        -selectforeground $colors(SystemHighlightText) \
        -lightcolor       $colors(SystemButtonFace) \
        -troughcolor      $colors(SystemScrollbar) \
        \
        -darkcolor Black \
        -selectborderwidth 0 \
        -font TkDefaultFont \
        ;
    
    ::ttk::style map "." \
        -foreground [list disabled $colors(SystemDisabledText)] \
        -background [list disabled $colors(SystemWindowFrame) \
                          pressed  $colors(SystemHighlight) \
                          active   $colors(SystemHighlight)] \
        ;
    
    # ttk widgets:
    ::ttk::style configure TButton \
        -width -8 -padding {5 1} -relief raised
    ::ttk::style configure TMenubutton \
        -width -11 -padding {5 1} -relief raised
    ::ttk::style configure TCheckbutton \
        -indicatorbackground "#ffffff" -indicatormargin {1 1 4 1}
    ::ttk::style configure TRadiobutton \
        -indicatorbackground "#ffffff" -indicatormargin {1 1 4 1}
    
    ::ttk::style configure TEntry \
        -fieldbackground $colors(SystemHighlight) \
        -foreground $colors(SystemWindowText) \
        -padding {2 0}
    ::ttk::style configure TCombobox \
        -fieldbackground $colors(SystemHighlight) \
        -foreground $colors(SystemWindowText) \
        -padding {2 0}
    
    ::ttk::style configure TNotebook.Tab \
        -padding {6 2 6 2}
    
    # tk widgets:
    ::ttk::style map Menu \
        -background [list active $colors(SystemMenu)] \
        -foreground [list disabled $colors(SystemMenuText)]
    
    ::ttk::style configure TreeCtrl \
        -background gray30 -itembackground {gray60 gray50} \
        -itemfill white -itemaccentfill yellow
  }
}


namespace eval ::tablelist:: {

  proc greyTheme {} {
    variable themeDefaults
    array set colors [array get ::ttk::theme::grey::colors]

    array set themeDefaults [list \
	-background		$colors(SystemWindow) \
	-foreground		$colors(SystemWindowText) \
	-disabledforeground	$colors(SystemDisabledText) \
	-stripebackground	#6e7c94 \
	-selectbackground	$colors(SystemHighlight) \
	-selectforeground	$colors(SystemHighlightText) \
	-selectborderwidth	0 \
	-font			TkTextFont \
        -labelbackground	#ece9d8 \
	-labeldisabledBg	$colors(SystemDisabledText) \
	-labelactiveBg		#c1d2ee \
	-labelpressedBg		#bab5ab \
	-labelforeground	black \
	-labeldisabledFg	$colors(SystemDisabledText) \
	-labelactiveFg		black \
	-labelpressedFg		black \
	-labelfont		TkDefaultFont \
	-labelborderwidth	2 \
	-labelpady		1 \
	-arrowcolor		#aca899 \
	-arrowstyle		flat9x5 \
	-showseparators         yes \
      ]

      # ???
      # for some reason, these options needs to be explicitely set:
      # option add *Tablelist.foreground       $themeDefaults(-foreground)
      # option add *Tablelist.background       $themeDefaults(-background)
      # option add *Tablelist.stripebackground $themeDefaults(-stripebackground)
  }
}


package provide ttk::theme::grey $::ttk::theme::grey::version
