# Kore-GTK - Copyright (C) 2004 Johann Oberdorfer,
#                               <Johann.Oberdorfer@googlemail.com>
# Original: Kore-GTK theme
# Link: http://art.gnome.org/themes/...
#
# $Id: kore.tcl, v 0.1 2007/07/12 oberdorfer  Exp $

package require Tk 8.4;                 # minimum version for Tile
package require tile 0.8;               # depends upon tile


namespace eval ttk {
  namespace eval theme {
    namespace eval kore {
      variable version 0.5
    }
  }
}

namespace eval ttk::theme::kore {
 
  variable I
  
  set thisDir  [file dirname [info script]]
  set imageDir [file join $thisDir "images"]
  set imageLib [file join $thisDir "ImageLib.tcl"] \
      
  # try to load image library file...
  if { [file exists $imageLib] } {
    
    source $imageLib
    array set I [array get images]
    
  } else {
    
    proc LoadImages {imgdir {patterns {*.gif}}} {
      foreach pattern $patterns {
        foreach file [glob -directory $imgdir $pattern] {
          set img [file tail [file rootname $file]]
          if {![info exists images($img)]} {
            set images($img) [image create photo -file $file]
          }
        }}
      return [array get images]
    }
    
    array set I [LoadImages $imageDir "*.gif"]
  }
  
  ttk::style theme create kore -parent clam -settings {
    
    # -----------------------------------------------------------------
    # Defaults
    # -----------------------------------------------------------------
    
    ttk::style configure "." \
        -background "Black" \
        -foreground "White" \
        -selectbackground "#4a6984" \
        -selectforeground "#ffffff" \
        -font TkDefaultFont \
        ;
    
    # I really like the mapping options!
    set stripe "#191919"
    
    ttk::style map "." \
        -foreground { disabled "#909090" } \
        -background [list \
	    disabled $stripe \
            pressed  "#626262" \
            active   "#222222" ]
    ;
    
    
    ttk::style configure TButton -padding {1 1} -width -11
    
    # -----------------------------------------------------------------
    # Troughs
    # -----------------------------------------------------------------
    
    ttk::style element create trough image $I(horizontal_trough) \
        -border 3
    ttk::style element create Vertical.Scrollbar.trough \
        image $I(vertical_trough) -border 2
    ttk::style element create Vertical.Scale.trough \
        image $I(vertical_trough) -border 2
    ttk::style element create Vertical.Progress.trough \
        image $I(vertical_trough) -border 2
    
    # -----------------------------------------------------------------
    # Buttons, Checkbuttons and Radiobuttons
    # -----------------------------------------------------------------
    
    ttk::style layout TButton {
      Button.background
      Button.button -children {
        Button.focus -children {
          Button.label
        }
      }
    }
    
    # {4 13 4 13}
    ttk::style element create button image \
        [list $I(button_norm) \
	      {pressed !disabled} $I(button_norm) \
              {active !disabled}  $I(button_pressed) \
              disabled            $I(button_norm)] \
        -border {4 15 4 15} -padding 2 -sticky news
    
    ttk::style element create Checkbutton.indicator image \
        [list $I(button_prelight) \
	      {selected !disabled} $I(checkbox_checked)] \
        -border 2 -width 10 -sticky w
    
    ttk::style element create Radiobutton.indicator image \
        [list $I(option_out) {selected !disabled} $I(option_in)] \
        -border 2 -width 20 -sticky w
    
    # Entry widgets.
    # --------------
    # ttk::style default TEntry \
    #    -selectborderwidth 1 -padding 0 -insertwidth 2 -font TkTextFont
    #    image $I(entry-shadow-in)
    
    # -----------------------------------------------------------------
    # Menubuttons:
    # -----------------------------------------------------------------
    
    ttk::style element create Menubutton.button image $I(menubar_option) \
        -border {7 10 29 15} -padding {7 4 29 4} -sticky news
    
    ttk::style element create Menubutton.indicator image \
        [list $I(menubar_option_arrow) \
        disabled $I(menubar_option_arrow_insensitive)] \
        -width 11 -sticky w -padding {0 0 18 0}
    
    
    # -----------------------------------------------------------------
    # Scrollbar
    # -----------------------------------------------------------------
    
    # ttk::style configure TScrollbar -width 16
    
    ttk::style element create Horizontal.Scrollbar.thumb image \
        [list $I(scrollbar_horizontal) \
              {active !disabled} $I(scrollbar_prelight_horizontal) \
	      disabled  $I(horizontal_trough)] \
        -border 7 -width 15 -height 0 -sticky news
    
    
    ttk::style element create Vertical.Scrollbar.thumb image \
        [list $I(scrollbar_vertical) \
              {active !disabled}  $I(scrollbar_prelight_vertical) \
	      disabled  $I(horizontal_trough)] \
        -border 7 -width 15 -height 15 -sticky news
    
    # -----------------------------------------------------------------
    # Scale
    # -----------------------------------------------------------------
    
    ttk::style element create Horizontal.Scale.slider image \
        [list $I(scrollbar_horizontal) \
        {active !disabled} $I(scrollbar_prelight_horizontal)] \
        -border 3 -width 30 -height 16
    
    
    ttk::style element create Vertical.Scale.slider image \
        [list $I(scrollbar_vertical) \
        {active !disabled} $I(scrollbar_prelight_vertical)] \
        -border 3 -width 16 -height 30
    
    
    # -----------------------------------------------------------------
    # Progress
    # -----------------------------------------------------------------
    
    ttk::style element create bar \
        image $I(scrollbar_prelight_horizontal) \
        -border 3
    ttk::style element create Vertical.Progress.bar \
        image $I(scrollbar_prelight_vertical) \
        -border 3
    
    # ------------------------------------------------------------------
    # Arrows
    # ------------------------------------------------------------------
    
    ttk::style element create uparrow image \
        [list $I(arrow_up_normal) \
	      {pressed !disabled} $I(arrow_up_clicked) \
              disabled            $I(arrow_up_insensitive)] -width 14
    ttk::style element create downarrow image \
        [list $I(arrow_down_normal) \
	      {pressed !disabled} $I(arrow_down_clicked) \
              disabled            $I(arrow_down_insensitive)] -width 14
    ttk::style element create leftarrow image \
        [list $I(arrow_left_normal) \
	      {pressed !disabled} $I(arrow_left_clicked) \
              disabled            $I(arrow_left_insensitive)] -height 14
    ttk::style element create rightarrow image \
        [list $I(arrow_right_normal) \
	      {pressed !disabled} $I(arrow_right_clicked) \
              disabled            $I(arrow_right_insensitive)] -height 14
    
    # Notebook parts
    
    ::ttk::style element create tab image \
        [list $I(notebook_inactive) \
	      {selected !disabled} $I(notebook_active) \
              active   $I(notebook_normal) \
              disabled $I(notebook_inactive)] \
        -sticky news \
        -border {5 5 10 2} -height 16 -sticky news

    
    # doesn't work properly:
    # -border {2 2 2 1} ;# -width 8
    # not required:
    # ttk::style default TNotebook.Tab -padding {4 2}
    # ttk::style default TNotebook -expandtab {2 1}
    
    ttk::style configure TNotebook.Tab -background "Orange"
    
    ## Labelframes.
    #
    ttk::style configure TLabelframe -borderwidth 2 -relief groove
    
    # -----------------------------------------------------------------
    # Frames parts
    # -----------------------------------------------------------------
    
    # This make it REALLY SLOW
    # ttk::style element create Frame.background image $I(window_background)
    # ttk::style element create Labelframe.background image $I(window_background)
    
  }
}


namespace eval ::tablelist:: {
  
  # from black theme:
  proc test_kore__Theme {} {
    variable themeDefaults
    
    array set themeDefaults [list \
        -foreground	  "White" \
        -background	  "Black" \
        -disabledforeground "DarkGrey" \
        -stripebackground	  "#191919" \
        -selectbackground	  "#4a6984" \
        -selectforeground	  "DarkRed" \
        -selectborderwidth 0 \
        -font		TkTextFont \
        -labelbackground	"#191919" \
        -labeldisabledBg	"#dcdad5" \
        -labelactiveBg	"#eeebe7" \
        -labelpressedBg	"#eeebe7" \
        -labelforeground	white \
        -labeldisabledFg	"#999999" \
        -labelactiveFg	white \
        -labelpressedFg	white \
        -labelfont	TkDefaultFont \
        -labelborderwidth	2 \
        -labelpady	1 \
        -arrowcolor	"" \
        -arrowstyle	sunken10x9 \
        ]
  }
  
  proc koreTheme {} {
    variable themeDefaults
    
    set stripe "#191919"
    array set themeDefaults [list \
        -background		"Black" \
        -foreground		"Grey" \
        -disabledforeground	"#909090" \
        -stripebackground	$stripe \
        -selectbackground	"LightGrey" \
        -selectforeground	"#222222" \
        -selectborderwidth	0 \
        -font			APP_FONT_STD_NORMAL \
        -labelforeground	"Grey" \
        -labelbackground	$stripe \
        -labelactiveFg		red \
        -labelactiveBg		$stripe \
        -labelpressedFg		$stripe \
        -labelpressedBg		"LightGrey" \
        -labeldisabledFg	green \
        -labeldisabledBg	$stripe \
        -labelfont		APP_FONT_STD_SMALL \
        -labelborderwidth	2 \
        -labelpady		2 \
        -arrowcolor		"LightBlue" \
        -arrowstyle		sunken10x9 \
        -showseparators         yes \
        ]
  }
}

# -------------------------------------------------------------------------
# -------------------------------------------------------------------------

package provide ttk::theme::kore $::ttk::theme::kore::version

