# sriv.tcl - Copyright (C) 2004 Pat Thoyts <patthoyts@users.sourceforge.net>
#
# $Id: srivlg.tcl,v 1.25 2004/10/05 16:15:57 jenglish Exp $
#
#

namespace eval ttk::theme::srivlg {
  
  package provide ttk::theme::srivlg 0.5.1
  
  variable I
  
  set thisDir  [file dirname [info script]]
  set imageDir [file join $thisDir "images"]
  set imageLib [file join $thisDir "ImageLib.tcl"] \
      
  # try to load image library file...
  if { [file exists $imageLib] } {
    
    source $imageLib
    array set I [array get images]
    
  } else {
    
    proc LoadImages {imgdir {patterns {*.gif}}} {
      foreach pattern $patterns {
        foreach file [glob -directory $imgdir $pattern] {
          set img [file tail [file rootname $file]]
          if {![info exists images($img)]} {
            set images($img) [image create photo -file $file]
          }
        }}
      return [array get images]
    }
    
    array set I [LoadImages $imageDir "*.gif"]
  }
  
  array set colors {
    -frame  	"#6699cc"
    -lighter	"#bcd2e8"
    -window	 	"#e6f3ff"
    -selectbg	"#ffff33"
    -selectfg	"#000000"
    -disabledfg	"#666666"
  }
  
  ::ttk::style theme create srivlg -settings {
    
    ::ttk::style configure . \
        -borderwidth 	1 \
        -background 	$colors(-frame) \
        -fieldbackground	$colors(-window) \
        -troughcolor	$colors(-lighter) \
        -selectbackground	$colors(-selectbg) \
        -selectforeground	$colors(-selectfg) \
        ;
    ::ttk::style map . -foreground [list disabled $colors(-disabledfg)]
    
    ## Buttons.
    #
        
    ::ttk::style layout TButton {
      Button.background
      Button.button -children {
        Button.focus -children {
          Button.label
        }
      }
    }
    
    ::ttk::style layout Toolbutton {
      Toolbutton.background
      Toolbutton.button -children {
        Toolbutton.focus -children {
          Toolbutton.label
        }
      }
    }
    
    ::ttk::style element create button image \
        [list $I(button-n) \
	      {pressed !disabled} $I(button-p) \
              {active !selected}  $I(button-h) \
              selected $I(button-s) \
              disabled $I(button-d)] \
        -border {8 6 8 16} -padding {6 6} -sticky news
    
    ########## red
    ::ttk::style layout Red.TButton {
      Button.background
      Button.button-red -children {
        Button.focus -children {
          Button.label
        }
      }
    }
    
    ::ttk::style element create button-red image \
        [list $I(button-red-n) \
	      {pressed !disabled} $I(button-p) \
              {active !selected}  $I(button-h) \
              selected $I(button-s) \
              disabled $I(button-d)] \
        -border {8 6 8 16} -padding {6 6} -sticky news
    
    ########## yellow
    ::ttk::style layout Yellow.TButton {
      Button.background
      Button.button-yellow -children {
        Button.focus -children {
          Button.label
        }
      }
    }
    
    ::ttk::style element create button-yellow image \
        [list $I(button-yellow-n) \
	      {pressed !disabled} $I(button-p) \
              {active !selected}  $I(button-h) \
              selected $I(button-s) \
              disabled $I(button-d)] \
	-border {8 6 8 16} -padding {6 6} -sticky news
    
    ########## green
    ::ttk::style layout Green.TButton {
      Button.background
      Button.button-green -children {
        Button.focus -children {
          Button.label
        }
      }
    }
    
    ::ttk::style element create button-green image \
        [list $I(button-green-n) \
	      {pressed !disabled} $I(button-p) \
              {active !selected}  $I(button-h) \
              selected $I(button-s) \
              disabled $I(button-d)] \
        -border {8 6 8 16} -padding {6 6} -sticky news
    
    ########## grey
    ::ttk::style layout Grey.TButton {
      Button.background
      Button.button-grey -children {
        Button.focus -children {
          Button.label
        }
      }
    }
    
    ::ttk::style element create button-grey image \
       [list $I(button-grey-n) \
	      {pressed !disabled} $I(button-p) \
              {active !selected}  $I(button-h) \
              selected $I(button-s) \
              disabled $I(button-d)] \
        -border {8 6 8 16} -padding {6 6} -sticky news \
 
    
    ########## violet
    ::ttk::style layout Violet.TButton {
      Button.background
      Button.button-violet -children {
        Button.focus -children {
          Button.label
        }
      }
    }
    
    ::ttk::style element create button-violet image \
        [list $I(button-violet-n) {pressed !disabled} $I(button-p) \
        {active !selected}  $I(button-h) \
        selected $I(button-s) \
        disabled $I(button-d)] \
        -border {8 6 8 16} -padding {6 6} -sticky news

    
    ########## orange
    ::ttk::style layout Orange.TButton {
      Button.background
      Button.button-orange -children {
        Button.focus -children {
          Button.label
        }
      }
    }
    
    ::ttk::style element create button-orange image \
       [list $I(button-orange-n) {pressed !disabled} $I(button-p) \
        {active !selected}  $I(button-h) \
        selected $I(button-s) \
        disabled $I(button-d)] \
	-border {8 6 8 16} -padding {6 6} -sticky news
 
    
    
    ::ttk::style configure TButton -padding {10 6} -font {Helvetica -12 bold}
    ::ttk::style configure Red.TButton -padding {10 6} -font {Helvetica -12 bold}
    ::ttk::style configure Green.TButton -padding {10 6} -font {Helvetica -12 bold}
    ::ttk::style configure Yellow.TButton -padding {10 6} -font {Helvetica -12 bold}
    ::ttk::style configure Orange.TButton -padding {10 6} -font {Helvetica -12 bold}
    ::ttk::style configure Violet.TButton -padding {10 6} -font {Helvetica -12 bold}
    ::ttk::style configure Grey.TButton -padding {10 6} -font {Helvetica -12 bold}
    # ::ttk::style configure TButton -padding {10 6} -font {Fixed -12 bold}
    
    #::ttk::style element create button image \
    #    [list $I(button-n) pressed $I(button-p)  active $I(button-h)] \
    #    -border 4 -sticky ew
    
    ::ttk::style element create Checkbutton.indicator image \
        [list $I(check-nu) \
        {!disabled active selected} $I(check-hc) \
        {!disabled active} $I(check-hu) \
        {!disabled selected} $I(check-nc) ] \
	-width 24 -sticky w 
    
    ::ttk::style element create Radiobutton.indicator image \
        [list $I(radio-nu) \
        {!disabled active selected} $I(radio-hc) \
        {!disabled active} $I(radio-hu) \
        selected $I(radio-nc) ] \
	-width 24 -sticky w
    
    
    # The layout for the menubutton is modified to have a button element
    # drawn on top of the background. This means we can have transparent
    # pixels in the button element. Also, the pixmap has a special
    # region on the right for the arrow. So we draw the indicator as a
    # sibling element to the button, and draw it after (ie on top of) the
    # button image.
    ::ttk::style layout TMenubutton {
      Menubutton.background
      Menubutton.button -children {
        Menubutton.focus -children {
          Menubutton.padding -children {
            Menubutton.label -side left -expand true
          }
        }
      }
      Menubutton.indicator -side right
    }
    ::ttk::style element create Menubutton.button image \
        [list $I(mbut-n) {active !disabled} $I(mbut-a) \
        {pressed !disabled} $I(mbut-a) \
        {disabled}          $I(mbut-d)] \
        -border {7 10 29 15} -padding {7 4 29 4} -sticky news
    ::ttk::style element create Menubutton.indicator image $I(mbut-arrow-n) \
        -width 11 -sticky w -padding {0 0 18 0}
    
    ## Toolbar buttons.
    #
    
    ::ttk::style element create Toolbutton.button image \
        [list $I(tbar-n) {pressed !disabled} $I(tbar-p) \
        {active !selected}   $I(tbar-a) \
        selected             $I(tbar-p)] \
	-border {2 8 2 16} -padding {2 2} -sticky news
    
    
    ## Entry widgets.
    #
    ::ttk::style configure TEntry \
        -selectborderwidth 1 -padding 2 -insertwidth 2 -font TkTextFont -borderwidth 3 -relief sunken
    
    ::ttk::style configure TCombobox \
        -selectborderwidth 1 -padding 2 -insertwidth 2 -font TkTextFont
    
    ## Notebooks.
    #
    
    ::ttk::style element create tab image \
        [list $I(tab-n) selected $I(tab-p) active $I(tab-p)] \
        -border {6 6 6 2} -height 12
    
    ## Scrollbars.
    #
    ::ttk::style layout Vertical.TScrollbar {
      Scrollbar.trough -children {
        Scrollbar.uparrow -side top
        Scrollbar.downarrow -side bottom
        Scrollbar.uparrow -side bottom
        Vertical.Scrollbar.thumb -side top -expand true -sticky ns
      }
    }
    
    ::ttk::style layout Horizontal.TScrollbar {
      Scrollbar.trough -children {
        Scrollbar.leftarrow -side left
        Scrollbar.rightarrow -side right
        Scrollbar.leftarrow -side right
        Horizontal.Scrollbar.thumb -side left -expand true -sticky we
      }
    }
    
    ::ttk::style element create Horizontal.Scrollbar.thumb image \
        [list $I(sb-thumb) {pressed !disabled} $I(sb-thumb-p)] -border 3
    
    ::ttk::style element create Vertical.Scrollbar.thumb image \
        [list $I(sb-vthumb) {pressed !disabled} $I(sb-vthumb-p)] -border 3
    
    foreach dir {up down left right} {
      ::ttk::style element create ${dir}arrow image \
          [list $I(arrow${dir}) \
          disabled $I(arrow${dir}) \
          pressed $I(arrow${dir}-p) \
          active $I(arrow${dir}-h)] \
          -border 1 -sticky {}
    }
    
    ## Scales.
    #
    ::ttk::style element create Scale.slider \
        image [list $I(slider) {pressed !disabled} $I(slider-p)]
    
    ::ttk::style element create Vertical.Scale.slider \
        image [list $I(vslider-p) {pressed !disabled} $I(vslider-p)]
    
    ::ttk::style element create Horizontal.Progress.bar \
        image $I(sb-thumb) -border 2
    ::ttk::style element create Vertical.Progress.bar \
        image $I(sb-vthumb) -border 2
  }
}

